@@ -271,6 +271,7 @@ _drm2_randr_create(void)
    const Eina_List *outputs;
    Ecore_Drm2_Output *output;
    unsigned int type;
+   E_Zone *zone;
 
    dev = ecore_evas_data_get(e_comp->ee, "device");
    if (!dev) return NULL;
@@ -355,6 +356,8 @@ _drm2_randr_create(void)
              s->info.modes = eina_list_append(s->info.modes, rmode);
           }
 
+        e_randr2_screen_modes_sort(s);
+
         if (e_randr2_cfg)
           cs = e_randr2_config_screen_find(s, e_randr2_cfg);
         if (cs)
@@ -439,6 +442,9 @@ _drm2_randr_create(void)
                }
           }
 
+        zone = e_zone_for_id_get(s->id);
+        if ((zone) && (!zone->output)) zone->output = s;
+
         r->screens = eina_list_append(r->screens, s);
      }
 
@@ -818,12 +824,12 @@ e_modapi_init(E_Module *m)
 
    ecore_evas_data_set(e_comp->ee, "comp", e_comp);
 
-   /* get the current screen geometry */
-   ecore_evas_screen_geometry_get(e_comp->ee, NULL, NULL, &w, &h);
-
    e_comp->screen = &drmiface;
 
    if (!e_comp_wl_init()) return NULL;
+
+   /* get the current screen geometry */
+   ecore_evas_screen_geometry_get(e_comp->ee, NULL, NULL, &w, &h);
    if (!e_comp_canvas_init(w, h)) return NULL;
 
    ecore_evas_pointer_xy_get(e_comp->ee, &e_comp_wl->ptr.x,
